# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: feast_spark/api/JobService.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from feast.core import DataSource_pb2 as feast_dot_core_dot_DataSource__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n feast_spark/api/JobService.proto\x12\x0f\x66\x65\x61st_spark.api\x1a\x1b\x66\x65\x61st/core/DataSource.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa6\x05\n\x03Job\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12,\n\x04type\x18\x02 \x01(\x0e\x32\x18.feast_spark.api.JobTypeR\x04type\x12\x32\n\x06status\x18\x03 \x01(\x0e\x32\x1a.feast_spark.api.JobStatusR\x06status\x12\x12\n\x04hash\x18\x04 \x01(\tR\x04hash\x12\x39\n\nstart_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tstartTime\x12\x45\n\tretrieval\x18\x06 \x01(\x0b\x32%.feast_spark.api.Job.RetrievalJobMetaH\x00R\tretrieval\x12S\n\x0f\x62\x61tch_ingestion\x18\x07 \x01(\x0b\x32(.feast_spark.api.Job.OfflineToOnlineMetaH\x00R\x0e\x62\x61tchIngestion\x12T\n\x10stream_ingestion\x18\x08 \x01(\x0b\x32\'.feast_spark.api.Job.StreamToOnlineMetaH\x00R\x0fstreamIngestion\x12\x17\n\x07log_uri\x18\t \x01(\tR\x06logUri\x12#\n\rerror_message\x18\n \x01(\tR\x0c\x65rrorMessage\x1a;\n\x10RetrievalJobMeta\x12\'\n\x0foutput_location\x18\x01 \x01(\tR\x0eoutputLocation\x1a\x34\n\x13OfflineToOnlineMeta\x12\x1d\n\ntable_name\x18\x01 \x01(\tR\ttableName\x1a\x33\n\x12StreamToOnlineMeta\x12\x1d\n\ntable_name\x18\x01 \x01(\tR\ttableNameB\x06\n\x04meta\"\xfd\x01\n\'StartOfflineToOnlineIngestionJobRequest\x12\x18\n\x07project\x18\x01 \x01(\tR\x07project\x12\x1d\n\ntable_name\x18\x02 \x01(\tR\ttableName\x12\x39\n\nstart_date\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tstartDate\x12\x35\n\x08\x65nd_date\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x07\x65ndDate\x12\'\n\x0f\x64\x65lta_ingestion\x18\x05 \x01(\x08R\x0e\x64\x65ltaIngestion\"\xb4\x01\n(StartOfflineToOnlineIngestionJobResponse\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12@\n\x0ejob_start_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0cjobStartTime\x12\x1d\n\ntable_name\x18\x03 \x01(\tR\ttableName\x12\x17\n\x07log_uri\x18\x04 \x01(\tR\x06logUri\"\xb9\x01\n*ScheduleOfflineToOnlineIngestionJobRequest\x12\x18\n\x07project\x18\x01 \x01(\tR\x07project\x12\x1d\n\ntable_name\x18\x02 \x01(\tR\ttableName\x12-\n\x12ingestion_timespan\x18\x03 \x01(\x05R\x11ingestionTimespan\x12#\n\rcron_schedule\x18\x04 \x01(\tR\x0c\x63ronSchedule\"-\n+ScheduleOfflineToOnlineIngestionJobResponse\"g\n,UnscheduleOfflineToOnlineIngestionJobRequest\x12\x18\n\x07project\x18\x01 \x01(\tR\x07project\x12\x1d\n\ntable_name\x18\x02 \x01(\tR\ttableName\"/\n-UnscheduleOfflineToOnlineIngestionJobResponse\"\xe6\x01\n\x1cGetHistoricalFeaturesRequest\x12!\n\x0c\x66\x65\x61ture_refs\x18\x01 \x03(\tR\x0b\x66\x65\x61tureRefs\x12;\n\rentity_source\x18\x02 \x01(\x0b\x32\x16.feast.core.DataSourceR\x0c\x65ntitySource\x12\x18\n\x07project\x18\x03 \x01(\tR\x07project\x12\'\n\x0foutput_location\x18\x04 \x01(\tR\x0eoutputLocation\x12#\n\routput_format\x18\x05 \x01(\tR\x0coutputFormat\"\xb2\x01\n\x1dGetHistoricalFeaturesResponse\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12&\n\x0foutput_file_uri\x18\x02 \x01(\tR\routputFileUri\x12@\n\x0ejob_start_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0cjobStartTime\x12\x17\n\x07log_uri\x18\x04 \x01(\tR\x06logUri\"y\n\x0fListJobsRequest\x12-\n\x12include_terminated\x18\x01 \x01(\x08R\x11includeTerminated\x12\x1d\n\ntable_name\x18\x02 \x01(\tR\ttableName\x12\x18\n\x07project\x18\x03 \x01(\tR\x07project\"<\n\x10ListJobsResponse\x12(\n\x04jobs\x18\x01 \x03(\x0b\x32\x14.feast_spark.api.JobR\x04jobs\"&\n\rGetJobRequest\x12\x15\n\x06job_id\x18\x01 \x01(\tR\x05jobId\"8\n\x0eGetJobResponse\x12&\n\x03job\x18\x01 \x01(\x0b\x32\x14.feast_spark.api.JobR\x03job\")\n\x10\x43\x61ncelJobRequest\x12\x15\n\x06job_id\x18\x01 \x01(\tR\x05jobId\"\x13\n\x11\x43\x61ncelJobResponse\"T\n\x17GetHealthMetricsRequest\x12\x18\n\x07project\x18\x01 \x01(\tR\x07project\x12\x1f\n\x0btable_names\x18\x02 \x03(\tR\ntableNames\"J\n\x18GetHealthMetricsResponse\x12\x16\n\x06passed\x18\x01 \x03(\tR\x06passed\x12\x16\n\x06\x66\x61iled\x18\x02 \x03(\tR\x06\x66\x61iled*`\n\x07JobType\x12\x0f\n\x0bINVALID_JOB\x10\x00\x12\x17\n\x13\x42\x41TCH_INGESTION_JOB\x10\x01\x12\x18\n\x14STREAM_INGESTION_JOB\x10\x02\x12\x11\n\rRETRIEVAL_JOB\x10\x04*~\n\tJobStatus\x12\x16\n\x12JOB_STATUS_INVALID\x10\x00\x12\x16\n\x12JOB_STATUS_PENDING\x10\x01\x12\x16\n\x12JOB_STATUS_RUNNING\x10\x02\x12\x13\n\x0fJOB_STATUS_DONE\x10\x03\x12\x14\n\x10JOB_STATUS_ERROR\x10\x04\x32\xc3\x07\n\nJobService\x12\x97\x01\n StartOfflineToOnlineIngestionJob\x12\x38.feast_spark.api.StartOfflineToOnlineIngestionJobRequest\x1a\x39.feast_spark.api.StartOfflineToOnlineIngestionJobResponse\x12\xa0\x01\n#ScheduleOfflineToOnlineIngestionJob\x12;.feast_spark.api.ScheduleOfflineToOnlineIngestionJobRequest\x1a<.feast_spark.api.ScheduleOfflineToOnlineIngestionJobResponse\x12\xa6\x01\n%UnscheduleOfflineToOnlineIngestionJob\x12=.feast_spark.api.UnscheduleOfflineToOnlineIngestionJobRequest\x1a>.feast_spark.api.UnscheduleOfflineToOnlineIngestionJobResponse\x12v\n\x15GetHistoricalFeatures\x12-.feast_spark.api.GetHistoricalFeaturesRequest\x1a..feast_spark.api.GetHistoricalFeaturesResponse\x12O\n\x08ListJobs\x12 .feast_spark.api.ListJobsRequest\x1a!.feast_spark.api.ListJobsResponse\x12R\n\tCancelJob\x12!.feast_spark.api.CancelJobRequest\x1a\".feast_spark.api.CancelJobResponse\x12I\n\x06GetJob\x12\x1e.feast_spark.api.GetJobRequest\x1a\x1f.feast_spark.api.GetJobResponse\x12g\n\x10GetHealthMetrics\x12(.feast_spark.api.GetHealthMetricsRequest\x1a).feast_spark.api.GetHealthMetricsResponseB\x86\x01\n$dev.caraml.store.protobuf.jobserviceB\x0fJobServiceProtoZMgithub.com/caraml-dev/caraml-store/caraml-store-sdk/go/protos/feast_spark/apib\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'feast_spark.api.JobService_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$dev.caraml.store.protobuf.jobserviceB\017JobServiceProtoZMgithub.com/caraml-dev/caraml-store/caraml-store-sdk/go/protos/feast_spark/api'
  _JOBTYPE._serialized_start=2547
  _JOBTYPE._serialized_end=2643
  _JOBSTATUS._serialized_start=2645
  _JOBSTATUS._serialized_end=2771
  _JOB._serialized_start=116
  _JOB._serialized_end=794
  _JOB_RETRIEVALJOBMETA._serialized_start=620
  _JOB_RETRIEVALJOBMETA._serialized_end=679
  _JOB_OFFLINETOONLINEMETA._serialized_start=681
  _JOB_OFFLINETOONLINEMETA._serialized_end=733
  _JOB_STREAMTOONLINEMETA._serialized_start=735
  _JOB_STREAMTOONLINEMETA._serialized_end=786
  _STARTOFFLINETOONLINEINGESTIONJOBREQUEST._serialized_start=797
  _STARTOFFLINETOONLINEINGESTIONJOBREQUEST._serialized_end=1050
  _STARTOFFLINETOONLINEINGESTIONJOBRESPONSE._serialized_start=1053
  _STARTOFFLINETOONLINEINGESTIONJOBRESPONSE._serialized_end=1233
  _SCHEDULEOFFLINETOONLINEINGESTIONJOBREQUEST._serialized_start=1236
  _SCHEDULEOFFLINETOONLINEINGESTIONJOBREQUEST._serialized_end=1421
  _SCHEDULEOFFLINETOONLINEINGESTIONJOBRESPONSE._serialized_start=1423
  _SCHEDULEOFFLINETOONLINEINGESTIONJOBRESPONSE._serialized_end=1468
  _UNSCHEDULEOFFLINETOONLINEINGESTIONJOBREQUEST._serialized_start=1470
  _UNSCHEDULEOFFLINETOONLINEINGESTIONJOBREQUEST._serialized_end=1573
  _UNSCHEDULEOFFLINETOONLINEINGESTIONJOBRESPONSE._serialized_start=1575
  _UNSCHEDULEOFFLINETOONLINEINGESTIONJOBRESPONSE._serialized_end=1622
  _GETHISTORICALFEATURESREQUEST._serialized_start=1625
  _GETHISTORICALFEATURESREQUEST._serialized_end=1855
  _GETHISTORICALFEATURESRESPONSE._serialized_start=1858
  _GETHISTORICALFEATURESRESPONSE._serialized_end=2036
  _LISTJOBSREQUEST._serialized_start=2038
  _LISTJOBSREQUEST._serialized_end=2159
  _LISTJOBSRESPONSE._serialized_start=2161
  _LISTJOBSRESPONSE._serialized_end=2221
  _GETJOBREQUEST._serialized_start=2223
  _GETJOBREQUEST._serialized_end=2261
  _GETJOBRESPONSE._serialized_start=2263
  _GETJOBRESPONSE._serialized_end=2319
  _CANCELJOBREQUEST._serialized_start=2321
  _CANCELJOBREQUEST._serialized_end=2362
  _CANCELJOBRESPONSE._serialized_start=2364
  _CANCELJOBRESPONSE._serialized_end=2383
  _GETHEALTHMETRICSREQUEST._serialized_start=2385
  _GETHEALTHMETRICSREQUEST._serialized_end=2469
  _GETHEALTHMETRICSRESPONSE._serialized_start=2471
  _GETHEALTHMETRICSRESPONSE._serialized_end=2545
  _JOBSERVICE._serialized_start=2774
  _JOBSERVICE._serialized_end=3737
# @@protoc_insertion_point(module_scope)



from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from feast.core import DataSource_pb2 as _DataSource_pb2
from feast.core import Feature_pb2 as _Feature_pb2
from feast.core import OnlineStore_pb2 as _OnlineStore_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class FeatureTable(_message.Message):
    __slots__ = ["meta", "spec"]
    META_FIELD_NUMBER: _ClassVar[int]
    SPEC_FIELD_NUMBER: _ClassVar[int]
    meta: FeatureTableMeta
    spec: FeatureTableSpec
    def __init__(self, spec: _Optional[_Union[FeatureTableSpec, _Mapping]] = ..., meta: _Optional[_Union[FeatureTableMeta, _Mapping]] = ...) -> None: ...

class FeatureTableMeta(_message.Message):
    __slots__ = ["created_timestamp", "hash", "last_updated_timestamp", "revision"]
    CREATED_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    HASH_FIELD_NUMBER: _ClassVar[int]
    LAST_UPDATED_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    REVISION_FIELD_NUMBER: _ClassVar[int]
    created_timestamp: _timestamp_pb2.Timestamp
    hash: str
    last_updated_timestamp: _timestamp_pb2.Timestamp
    revision: int
    def __init__(self, created_timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., last_updated_timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., revision: _Optional[int] = ..., hash: _Optional[str] = ...) -> None: ...

class FeatureTableSpec(_message.Message):
    __slots__ = ["batch_source", "entities", "features", "labels", "max_age", "name", "online_store", "staleness_threshold", "stream_source"]
    class LabelsEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    BATCH_SOURCE_FIELD_NUMBER: _ClassVar[int]
    ENTITIES_FIELD_NUMBER: _ClassVar[int]
    FEATURES_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    MAX_AGE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    ONLINE_STORE_FIELD_NUMBER: _ClassVar[int]
    STALENESS_THRESHOLD_FIELD_NUMBER: _ClassVar[int]
    STREAM_SOURCE_FIELD_NUMBER: _ClassVar[int]
    batch_source: _DataSource_pb2.DataSource
    entities: _containers.RepeatedScalarFieldContainer[str]
    features: _containers.RepeatedCompositeFieldContainer[_Feature_pb2.FeatureSpec]
    labels: _containers.ScalarMap[str, str]
    max_age: _duration_pb2.Duration
    name: str
    online_store: _OnlineStore_pb2.OnlineStore
    staleness_threshold: _duration_pb2.Duration
    stream_source: _DataSource_pb2.DataSource
    def __init__(self, name: _Optional[str] = ..., entities: _Optional[_Iterable[str]] = ..., features: _Optional[_Iterable[_Union[_Feature_pb2.FeatureSpec, _Mapping]]] = ..., labels: _Optional[_Mapping[str, str]] = ..., max_age: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., batch_source: _Optional[_Union[_DataSource_pb2.DataSource, _Mapping]] = ..., stream_source: _Optional[_Union[_DataSource_pb2.DataSource, _Mapping]] = ..., staleness_threshold: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., online_store: _Optional[_Union[_OnlineStore_pb2.OnlineStore, _Mapping]] = ...) -> None: ...



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from feast.types import Value_pb2 as _Value_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor
INGESTION_FAILURE: FieldStatus
INVALID: FieldStatus
NOT_FOUND: FieldStatus
NULL_VALUE: FieldStatus
OUTSIDE_MAX_AGE: FieldStatus
PRESENT: FieldStatus

class FeatureReference(_message.Message):
    __slots__ = ["feature_table", "name"]
    FEATURE_TABLE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    feature_table: str
    name: str
    def __init__(self, feature_table: _Optional[str] = ..., name: _Optional[str] = ...) -> None: ...

class FieldList(_message.Message):
    __slots__ = ["val"]
    VAL_FIELD_NUMBER: _ClassVar[int]
    val: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, val: _Optional[_Iterable[str]] = ...) -> None: ...

class GetFeastServingInfoRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetFeastServingInfoResponse(_message.Message):
    __slots__ = ["version"]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    version: str
    def __init__(self, version: _Optional[str] = ...) -> None: ...

class GetOnlineFeaturesRequest(_message.Message):
    __slots__ = ["entity_rows", "features", "project"]
    class EntityRow(_message.Message):
        __slots__ = ["fields", "timestamp"]
        class FieldsEntry(_message.Message):
            __slots__ = ["key", "value"]
            KEY_FIELD_NUMBER: _ClassVar[int]
            VALUE_FIELD_NUMBER: _ClassVar[int]
            key: str
            value: _Value_pb2.Value
            def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[_Value_pb2.Value, _Mapping]] = ...) -> None: ...
        FIELDS_FIELD_NUMBER: _ClassVar[int]
        TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
        fields: _containers.MessageMap[str, _Value_pb2.Value]
        timestamp: _timestamp_pb2.Timestamp
        def __init__(self, timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., fields: _Optional[_Mapping[str, _Value_pb2.Value]] = ...) -> None: ...
    ENTITY_ROWS_FIELD_NUMBER: _ClassVar[int]
    FEATURES_FIELD_NUMBER: _ClassVar[int]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    entity_rows: _containers.RepeatedCompositeFieldContainer[GetOnlineFeaturesRequest.EntityRow]
    features: _containers.RepeatedCompositeFieldContainer[FeatureReference]
    project: str
    def __init__(self, features: _Optional[_Iterable[_Union[FeatureReference, _Mapping]]] = ..., entity_rows: _Optional[_Iterable[_Union[GetOnlineFeaturesRequest.EntityRow, _Mapping]]] = ..., project: _Optional[str] = ...) -> None: ...

class GetOnlineFeaturesResponse(_message.Message):
    __slots__ = ["metadata", "results"]
    class FieldVector(_message.Message):
        __slots__ = ["statuses", "values"]
        STATUSES_FIELD_NUMBER: _ClassVar[int]
        VALUES_FIELD_NUMBER: _ClassVar[int]
        statuses: _containers.RepeatedScalarFieldContainer[FieldStatus]
        values: _containers.RepeatedCompositeFieldContainer[_Value_pb2.Value]
        def __init__(self, values: _Optional[_Iterable[_Union[_Value_pb2.Value, _Mapping]]] = ..., statuses: _Optional[_Iterable[_Union[FieldStatus, str]]] = ...) -> None: ...
    METADATA_FIELD_NUMBER: _ClassVar[int]
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    metadata: GetOnlineFeaturesResponseMetadata
    results: _containers.RepeatedCompositeFieldContainer[GetOnlineFeaturesResponse.FieldVector]
    def __init__(self, metadata: _Optional[_Union[GetOnlineFeaturesResponseMetadata, _Mapping]] = ..., results: _Optional[_Iterable[_Union[GetOnlineFeaturesResponse.FieldVector, _Mapping]]] = ...) -> None: ...

class GetOnlineFeaturesResponseMetadata(_message.Message):
    __slots__ = ["field_names"]
    FIELD_NAMES_FIELD_NUMBER: _ClassVar[int]
    field_names: FieldList
    def __init__(self, field_names: _Optional[_Union[FieldList, _Mapping]] = ...) -> None: ...

class GetOnlineFeaturesResponseV2(_message.Message):
    __slots__ = ["field_values"]
    class FieldValues(_message.Message):
        __slots__ = ["fields", "statuses"]
        class FieldsEntry(_message.Message):
            __slots__ = ["key", "value"]
            KEY_FIELD_NUMBER: _ClassVar[int]
            VALUE_FIELD_NUMBER: _ClassVar[int]
            key: str
            value: _Value_pb2.Value
            def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[_Value_pb2.Value, _Mapping]] = ...) -> None: ...
        class StatusesEntry(_message.Message):
            __slots__ = ["key", "value"]
            KEY_FIELD_NUMBER: _ClassVar[int]
            VALUE_FIELD_NUMBER: _ClassVar[int]
            key: str
            value: FieldStatus
            def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[FieldStatus, str]] = ...) -> None: ...
        FIELDS_FIELD_NUMBER: _ClassVar[int]
        STATUSES_FIELD_NUMBER: _ClassVar[int]
        fields: _containers.MessageMap[str, _Value_pb2.Value]
        statuses: _containers.ScalarMap[str, FieldStatus]
        def __init__(self, fields: _Optional[_Mapping[str, _Value_pb2.Value]] = ..., statuses: _Optional[_Mapping[str, FieldStatus]] = ...) -> None: ...
    FIELD_VALUES_FIELD_NUMBER: _ClassVar[int]
    field_values: _containers.RepeatedCompositeFieldContainer[GetOnlineFeaturesResponseV2.FieldValues]
    def __init__(self, field_values: _Optional[_Iterable[_Union[GetOnlineFeaturesResponseV2.FieldValues, _Mapping]]] = ...) -> None: ...

class FieldStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []



from feast.core import Entity_pb2 as _Entity_pb2
from feast.core import Feature_pb2 as _Feature_pb2
from feast.core import FeatureTable_pb2 as _FeatureTable_pb2
from feast.core import OnlineStore_pb2 as _OnlineStore_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ApplyEntityRequest(_message.Message):
    __slots__ = ["project", "spec"]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    SPEC_FIELD_NUMBER: _ClassVar[int]
    project: str
    spec: _Entity_pb2.EntitySpec
    def __init__(self, spec: _Optional[_Union[_Entity_pb2.EntitySpec, _Mapping]] = ..., project: _Optional[str] = ...) -> None: ...

class ApplyEntityResponse(_message.Message):
    __slots__ = ["entity"]
    ENTITY_FIELD_NUMBER: _ClassVar[int]
    entity: _Entity_pb2.Entity
    def __init__(self, entity: _Optional[_Union[_Entity_pb2.Entity, _Mapping]] = ...) -> None: ...

class ApplyFeatureTableRequest(_message.Message):
    __slots__ = ["project", "table_spec"]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    TABLE_SPEC_FIELD_NUMBER: _ClassVar[int]
    project: str
    table_spec: _FeatureTable_pb2.FeatureTableSpec
    def __init__(self, project: _Optional[str] = ..., table_spec: _Optional[_Union[_FeatureTable_pb2.FeatureTableSpec, _Mapping]] = ...) -> None: ...

class ApplyFeatureTableResponse(_message.Message):
    __slots__ = ["table"]
    TABLE_FIELD_NUMBER: _ClassVar[int]
    table: _FeatureTable_pb2.FeatureTable
    def __init__(self, table: _Optional[_Union[_FeatureTable_pb2.FeatureTable, _Mapping]] = ...) -> None: ...

class ArchiveOnlineStoreRequest(_message.Message):
    __slots__ = ["name"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class ArchiveOnlineStoreResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ArchiveProjectRequest(_message.Message):
    __slots__ = ["name"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class ArchiveProjectResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class CreateProjectRequest(_message.Message):
    __slots__ = ["name"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class CreateProjectResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DeleteFeatureTableRequest(_message.Message):
    __slots__ = ["name", "project"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    name: str
    project: str
    def __init__(self, project: _Optional[str] = ..., name: _Optional[str] = ...) -> None: ...

class DeleteFeatureTableResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetEntityRequest(_message.Message):
    __slots__ = ["name", "project"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    name: str
    project: str
    def __init__(self, name: _Optional[str] = ..., project: _Optional[str] = ...) -> None: ...

class GetEntityResponse(_message.Message):
    __slots__ = ["entity"]
    ENTITY_FIELD_NUMBER: _ClassVar[int]
    entity: _Entity_pb2.Entity
    def __init__(self, entity: _Optional[_Union[_Entity_pb2.Entity, _Mapping]] = ...) -> None: ...

class GetFeastCoreVersionRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetFeastCoreVersionResponse(_message.Message):
    __slots__ = ["version"]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    version: str
    def __init__(self, version: _Optional[str] = ...) -> None: ...

class GetFeatureTableRequest(_message.Message):
    __slots__ = ["name", "project"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    name: str
    project: str
    def __init__(self, project: _Optional[str] = ..., name: _Optional[str] = ...) -> None: ...

class GetFeatureTableResponse(_message.Message):
    __slots__ = ["table"]
    TABLE_FIELD_NUMBER: _ClassVar[int]
    table: _FeatureTable_pb2.FeatureTable
    def __init__(self, table: _Optional[_Union[_FeatureTable_pb2.FeatureTable, _Mapping]] = ...) -> None: ...

class GetOnlineStoreRequest(_message.Message):
    __slots__ = ["name"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class GetOnlineStoreResponse(_message.Message):
    __slots__ = ["online_store", "status"]
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    ACTIVE: GetOnlineStoreResponse.Status
    ARCHIVED: GetOnlineStoreResponse.Status
    ONLINE_STORE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    online_store: _OnlineStore_pb2.OnlineStore
    status: GetOnlineStoreResponse.Status
    def __init__(self, online_store: _Optional[_Union[_OnlineStore_pb2.OnlineStore, _Mapping]] = ..., status: _Optional[_Union[GetOnlineStoreResponse.Status, str]] = ...) -> None: ...

class ListEntitiesRequest(_message.Message):
    __slots__ = ["filter"]
    class Filter(_message.Message):
        __slots__ = ["labels", "project"]
        class LabelsEntry(_message.Message):
            __slots__ = ["key", "value"]
            KEY_FIELD_NUMBER: _ClassVar[int]
            VALUE_FIELD_NUMBER: _ClassVar[int]
            key: str
            value: str
            def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
        LABELS_FIELD_NUMBER: _ClassVar[int]
        PROJECT_FIELD_NUMBER: _ClassVar[int]
        labels: _containers.ScalarMap[str, str]
        project: str
        def __init__(self, project: _Optional[str] = ..., labels: _Optional[_Mapping[str, str]] = ...) -> None: ...
    FILTER_FIELD_NUMBER: _ClassVar[int]
    filter: ListEntitiesRequest.Filter
    def __init__(self, filter: _Optional[_Union[ListEntitiesRequest.Filter, _Mapping]] = ...) -> None: ...

class ListEntitiesResponse(_message.Message):
    __slots__ = ["entities"]
    ENTITIES_FIELD_NUMBER: _ClassVar[int]
    entities: _containers.RepeatedCompositeFieldContainer[_Entity_pb2.Entity]
    def __init__(self, entities: _Optional[_Iterable[_Union[_Entity_pb2.Entity, _Mapping]]] = ...) -> None: ...

class ListFeatureTablesRequest(_message.Message):
    __slots__ = ["filter"]
    class Filter(_message.Message):
        __slots__ = ["labels", "project"]
        class LabelsEntry(_message.Message):
            __slots__ = ["key", "value"]
            KEY_FIELD_NUMBER: _ClassVar[int]
            VALUE_FIELD_NUMBER: _ClassVar[int]
            key: str
            value: str
            def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
        LABELS_FIELD_NUMBER: _ClassVar[int]
        PROJECT_FIELD_NUMBER: _ClassVar[int]
        labels: _containers.ScalarMap[str, str]
        project: str
        def __init__(self, project: _Optional[str] = ..., labels: _Optional[_Mapping[str, str]] = ...) -> None: ...
    FILTER_FIELD_NUMBER: _ClassVar[int]
    filter: ListFeatureTablesRequest.Filter
    def __init__(self, filter: _Optional[_Union[ListFeatureTablesRequest.Filter, _Mapping]] = ...) -> None: ...

class ListFeatureTablesResponse(_message.Message):
    __slots__ = ["tables"]
    TABLES_FIELD_NUMBER: _ClassVar[int]
    tables: _containers.RepeatedCompositeFieldContainer[_FeatureTable_pb2.FeatureTable]
    def __init__(self, tables: _Optional[_Iterable[_Union[_FeatureTable_pb2.FeatureTable, _Mapping]]] = ...) -> None: ...

class ListFeaturesRequest(_message.Message):
    __slots__ = ["filter"]
    class Filter(_message.Message):
        __slots__ = ["entities", "labels", "project"]
        class LabelsEntry(_message.Message):
            __slots__ = ["key", "value"]
            KEY_FIELD_NUMBER: _ClassVar[int]
            VALUE_FIELD_NUMBER: _ClassVar[int]
            key: str
            value: str
            def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
        ENTITIES_FIELD_NUMBER: _ClassVar[int]
        LABELS_FIELD_NUMBER: _ClassVar[int]
        PROJECT_FIELD_NUMBER: _ClassVar[int]
        entities: _containers.RepeatedScalarFieldContainer[str]
        labels: _containers.ScalarMap[str, str]
        project: str
        def __init__(self, labels: _Optional[_Mapping[str, str]] = ..., entities: _Optional[_Iterable[str]] = ..., project: _Optional[str] = ...) -> None: ...
    FILTER_FIELD_NUMBER: _ClassVar[int]
    filter: ListFeaturesRequest.Filter
    def __init__(self, filter: _Optional[_Union[ListFeaturesRequest.Filter, _Mapping]] = ...) -> None: ...

class ListFeaturesResponse(_message.Message):
    __slots__ = ["features"]
    class FeaturesEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: _Feature_pb2.FeatureSpec
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[_Feature_pb2.FeatureSpec, _Mapping]] = ...) -> None: ...
    FEATURES_FIELD_NUMBER: _ClassVar[int]
    features: _containers.MessageMap[str, _Feature_pb2.FeatureSpec]
    def __init__(self, features: _Optional[_Mapping[str, _Feature_pb2.FeatureSpec]] = ...) -> None: ...

class ListOnlineStoresRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ListOnlineStoresResponse(_message.Message):
    __slots__ = ["online_store"]
    ONLINE_STORE_FIELD_NUMBER: _ClassVar[int]
    online_store: _containers.RepeatedCompositeFieldContainer[_OnlineStore_pb2.OnlineStore]
    def __init__(self, online_store: _Optional[_Iterable[_Union[_OnlineStore_pb2.OnlineStore, _Mapping]]] = ...) -> None: ...

class ListProjectsRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ListProjectsResponse(_message.Message):
    __slots__ = ["projects"]
    PROJECTS_FIELD_NUMBER: _ClassVar[int]
    projects: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, projects: _Optional[_Iterable[str]] = ...) -> None: ...

class RegisterOnlineStoreRequest(_message.Message):
    __slots__ = ["online_store"]
    ONLINE_STORE_FIELD_NUMBER: _ClassVar[int]
    online_store: _OnlineStore_pb2.OnlineStore
    def __init__(self, online_store: _Optional[_Union[_OnlineStore_pb2.OnlineStore, _Mapping]] = ...) -> None: ...

class RegisterOnlineStoreResponse(_message.Message):
    __slots__ = ["online_store", "status"]
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    NO_CHANGE: RegisterOnlineStoreResponse.Status
    ONLINE_STORE_FIELD_NUMBER: _ClassVar[int]
    REGISTERED: RegisterOnlineStoreResponse.Status
    STATUS_FIELD_NUMBER: _ClassVar[int]
    UPDATED: RegisterOnlineStoreResponse.Status
    online_store: _OnlineStore_pb2.OnlineStore
    status: RegisterOnlineStoreResponse.Status
    def __init__(self, online_store: _Optional[_Union[_OnlineStore_pb2.OnlineStore, _Mapping]] = ..., status: _Optional[_Union[RegisterOnlineStoreResponse.Status, str]] = ...) -> None: ...



from feast.types import Value_pb2 as _Value_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Field(_message.Message):
    __slots__ = ["name", "value"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    name: str
    value: _Value_pb2.Value
    def __init__(self, name: _Optional[str] = ..., value: _Optional[_Union[_Value_pb2.Value, _Mapping]] = ...) -> None: ...



from feast.core import DataSource_pb2 as _DataSource_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

BATCH_INGESTION_JOB: JobType
DESCRIPTOR: _descriptor.FileDescriptor
INVALID_JOB: JobType
JOB_STATUS_DONE: JobStatus
JOB_STATUS_ERROR: JobStatus
JOB_STATUS_INVALID: JobStatus
JOB_STATUS_PENDING: JobStatus
JOB_STATUS_RUNNING: JobStatus
RETRIEVAL_JOB: JobType
STREAM_INGESTION_JOB: JobType

class CancelJobRequest(_message.Message):
    __slots__ = ["job_id"]
    JOB_ID_FIELD_NUMBER: _ClassVar[int]
    job_id: str
    def __init__(self, job_id: _Optional[str] = ...) -> None: ...

class CancelJobResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetHealthMetricsRequest(_message.Message):
    __slots__ = ["project", "table_names"]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    TABLE_NAMES_FIELD_NUMBER: _ClassVar[int]
    project: str
    table_names: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, project: _Optional[str] = ..., table_names: _Optional[_Iterable[str]] = ...) -> None: ...

class GetHealthMetricsResponse(_message.Message):
    __slots__ = ["failed", "passed"]
    FAILED_FIELD_NUMBER: _ClassVar[int]
    PASSED_FIELD_NUMBER: _ClassVar[int]
    failed: _containers.RepeatedScalarFieldContainer[str]
    passed: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, passed: _Optional[_Iterable[str]] = ..., failed: _Optional[_Iterable[str]] = ...) -> None: ...

class GetHistoricalFeaturesRequest(_message.Message):
    __slots__ = ["entity_source", "feature_refs", "output_format", "output_location", "project"]
    ENTITY_SOURCE_FIELD_NUMBER: _ClassVar[int]
    FEATURE_REFS_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_FORMAT_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_LOCATION_FIELD_NUMBER: _ClassVar[int]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    entity_source: _DataSource_pb2.DataSource
    feature_refs: _containers.RepeatedScalarFieldContainer[str]
    output_format: str
    output_location: str
    project: str
    def __init__(self, feature_refs: _Optional[_Iterable[str]] = ..., entity_source: _Optional[_Union[_DataSource_pb2.DataSource, _Mapping]] = ..., project: _Optional[str] = ..., output_location: _Optional[str] = ..., output_format: _Optional[str] = ...) -> None: ...

class GetHistoricalFeaturesResponse(_message.Message):
    __slots__ = ["id", "job_start_time", "log_uri", "output_file_uri"]
    ID_FIELD_NUMBER: _ClassVar[int]
    JOB_START_TIME_FIELD_NUMBER: _ClassVar[int]
    LOG_URI_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_FILE_URI_FIELD_NUMBER: _ClassVar[int]
    id: str
    job_start_time: _timestamp_pb2.Timestamp
    log_uri: str
    output_file_uri: str
    def __init__(self, id: _Optional[str] = ..., output_file_uri: _Optional[str] = ..., job_start_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., log_uri: _Optional[str] = ...) -> None: ...

class GetJobRequest(_message.Message):
    __slots__ = ["job_id"]
    JOB_ID_FIELD_NUMBER: _ClassVar[int]
    job_id: str
    def __init__(self, job_id: _Optional[str] = ...) -> None: ...

class GetJobResponse(_message.Message):
    __slots__ = ["job"]
    JOB_FIELD_NUMBER: _ClassVar[int]
    job: Job
    def __init__(self, job: _Optional[_Union[Job, _Mapping]] = ...) -> None: ...

class Job(_message.Message):
    __slots__ = ["batch_ingestion", "error_message", "hash", "id", "log_uri", "retrieval", "start_time", "status", "stream_ingestion", "type"]
    class OfflineToOnlineMeta(_message.Message):
        __slots__ = ["table_name"]
        TABLE_NAME_FIELD_NUMBER: _ClassVar[int]
        table_name: str
        def __init__(self, table_name: _Optional[str] = ...) -> None: ...
    class RetrievalJobMeta(_message.Message):
        __slots__ = ["output_location"]
        OUTPUT_LOCATION_FIELD_NUMBER: _ClassVar[int]
        output_location: str
        def __init__(self, output_location: _Optional[str] = ...) -> None: ...
    class StreamToOnlineMeta(_message.Message):
        __slots__ = ["table_name"]
        TABLE_NAME_FIELD_NUMBER: _ClassVar[int]
        table_name: str
        def __init__(self, table_name: _Optional[str] = ...) -> None: ...
    BATCH_INGESTION_FIELD_NUMBER: _ClassVar[int]
    ERROR_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    HASH_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    LOG_URI_FIELD_NUMBER: _ClassVar[int]
    RETRIEVAL_FIELD_NUMBER: _ClassVar[int]
    START_TIME_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    STREAM_INGESTION_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    batch_ingestion: Job.OfflineToOnlineMeta
    error_message: str
    hash: str
    id: str
    log_uri: str
    retrieval: Job.RetrievalJobMeta
    start_time: _timestamp_pb2.Timestamp
    status: JobStatus
    stream_ingestion: Job.StreamToOnlineMeta
    type: JobType
    def __init__(self, id: _Optional[str] = ..., type: _Optional[_Union[JobType, str]] = ..., status: _Optional[_Union[JobStatus, str]] = ..., hash: _Optional[str] = ..., start_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., retrieval: _Optional[_Union[Job.RetrievalJobMeta, _Mapping]] = ..., batch_ingestion: _Optional[_Union[Job.OfflineToOnlineMeta, _Mapping]] = ..., stream_ingestion: _Optional[_Union[Job.StreamToOnlineMeta, _Mapping]] = ..., log_uri: _Optional[str] = ..., error_message: _Optional[str] = ...) -> None: ...

class ListJobsRequest(_message.Message):
    __slots__ = ["include_terminated", "project", "table_name"]
    INCLUDE_TERMINATED_FIELD_NUMBER: _ClassVar[int]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    TABLE_NAME_FIELD_NUMBER: _ClassVar[int]
    include_terminated: bool
    project: str
    table_name: str
    def __init__(self, include_terminated: bool = ..., table_name: _Optional[str] = ..., project: _Optional[str] = ...) -> None: ...

class ListJobsResponse(_message.Message):
    __slots__ = ["jobs"]
    JOBS_FIELD_NUMBER: _ClassVar[int]
    jobs: _containers.RepeatedCompositeFieldContainer[Job]
    def __init__(self, jobs: _Optional[_Iterable[_Union[Job, _Mapping]]] = ...) -> None: ...

class ScheduleOfflineToOnlineIngestionJobRequest(_message.Message):
    __slots__ = ["cron_schedule", "ingestion_timespan", "project", "table_name"]
    CRON_SCHEDULE_FIELD_NUMBER: _ClassVar[int]
    INGESTION_TIMESPAN_FIELD_NUMBER: _ClassVar[int]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    TABLE_NAME_FIELD_NUMBER: _ClassVar[int]
    cron_schedule: str
    ingestion_timespan: int
    project: str
    table_name: str
    def __init__(self, project: _Optional[str] = ..., table_name: _Optional[str] = ..., ingestion_timespan: _Optional[int] = ..., cron_schedule: _Optional[str] = ...) -> None: ...

class ScheduleOfflineToOnlineIngestionJobResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class StartOfflineToOnlineIngestionJobRequest(_message.Message):
    __slots__ = ["delta_ingestion", "end_date", "project", "start_date", "table_name"]
    DELTA_INGESTION_FIELD_NUMBER: _ClassVar[int]
    END_DATE_FIELD_NUMBER: _ClassVar[int]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    START_DATE_FIELD_NUMBER: _ClassVar[int]
    TABLE_NAME_FIELD_NUMBER: _ClassVar[int]
    delta_ingestion: bool
    end_date: _timestamp_pb2.Timestamp
    project: str
    start_date: _timestamp_pb2.Timestamp
    table_name: str
    def __init__(self, project: _Optional[str] = ..., table_name: _Optional[str] = ..., start_date: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., end_date: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., delta_ingestion: bool = ...) -> None: ...

class StartOfflineToOnlineIngestionJobResponse(_message.Message):
    __slots__ = ["id", "job_start_time", "log_uri", "table_name"]
    ID_FIELD_NUMBER: _ClassVar[int]
    JOB_START_TIME_FIELD_NUMBER: _ClassVar[int]
    LOG_URI_FIELD_NUMBER: _ClassVar[int]
    TABLE_NAME_FIELD_NUMBER: _ClassVar[int]
    id: str
    job_start_time: _timestamp_pb2.Timestamp
    log_uri: str
    table_name: str
    def __init__(self, id: _Optional[str] = ..., job_start_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., table_name: _Optional[str] = ..., log_uri: _Optional[str] = ...) -> None: ...

class UnscheduleOfflineToOnlineIngestionJobRequest(_message.Message):
    __slots__ = ["project", "table_name"]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    TABLE_NAME_FIELD_NUMBER: _ClassVar[int]
    project: str
    table_name: str
    def __init__(self, project: _Optional[str] = ..., table_name: _Optional[str] = ...) -> None: ...

class UnscheduleOfflineToOnlineIngestionJobResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class JobType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []

class JobStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class SparkOverride(_message.Message):
    __slots__ = ["driver_cpu", "driver_memory", "executor_cpu", "executor_memory"]
    DRIVER_CPU_FIELD_NUMBER: _ClassVar[int]
    DRIVER_MEMORY_FIELD_NUMBER: _ClassVar[int]
    EXECUTOR_CPU_FIELD_NUMBER: _ClassVar[int]
    EXECUTOR_MEMORY_FIELD_NUMBER: _ClassVar[int]
    driver_cpu: int
    driver_memory: str
    executor_cpu: int
    executor_memory: str
    def __init__(self, driver_cpu: _Optional[int] = ..., driver_memory: _Optional[str] = ..., executor_cpu: _Optional[int] = ..., executor_memory: _Optional[str] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class FileFormat(_message.Message):
    __slots__ = ["parquet_format"]
    class ParquetFormat(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    PARQUET_FORMAT_FIELD_NUMBER: _ClassVar[int]
    parquet_format: FileFormat.ParquetFormat
    def __init__(self, parquet_format: _Optional[_Union[FileFormat.ParquetFormat, _Mapping]] = ...) -> None: ...

class StreamFormat(_message.Message):
    __slots__ = ["avro_format", "proto_format"]
    class AvroFormat(_message.Message):
        __slots__ = ["schema_json"]
        SCHEMA_JSON_FIELD_NUMBER: _ClassVar[int]
        schema_json: str
        def __init__(self, schema_json: _Optional[str] = ...) -> None: ...
    class ProtoFormat(_message.Message):
        __slots__ = ["class_path"]
        CLASS_PATH_FIELD_NUMBER: _ClassVar[int]
        class_path: str
        def __init__(self, class_path: _Optional[str] = ...) -> None: ...
    AVRO_FORMAT_FIELD_NUMBER: _ClassVar[int]
    PROTO_FORMAT_FIELD_NUMBER: _ClassVar[int]
    avro_format: StreamFormat.AvroFormat
    proto_format: StreamFormat.ProtoFormat
    def __init__(self, avro_format: _Optional[_Union[StreamFormat.AvroFormat, _Mapping]] = ..., proto_format: _Optional[_Union[StreamFormat.ProtoFormat, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: feast/serving/ServingService.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from feast.types import Value_pb2 as feast_dot_types_dot_Value__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"feast/serving/ServingService.proto\x12\rfeast.serving\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17\x66\x65\x61st/types/Value.proto\"\x1c\n\x1aGetFeastServingInfoRequest\"7\n\x1bGetFeastServingInfoResponse\x12\x18\n\x07version\x18\x01 \x01(\tR\x07version\"K\n\x10\x46\x65\x61tureReference\x12#\n\rfeature_table\x18\x01 \x01(\tR\x0c\x66\x65\x61tureTable\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\"\xb3\x03\n\x18GetOnlineFeaturesRequest\x12;\n\x08\x66\x65\x61tures\x18\x04 \x03(\x0b\x32\x1f.feast.serving.FeatureReferenceR\x08\x66\x65\x61tures\x12R\n\x0b\x65ntity_rows\x18\x02 \x03(\x0b\x32\x31.feast.serving.GetOnlineFeaturesRequest.EntityRowR\nentityRows\x12\x18\n\x07project\x18\x05 \x01(\tR\x07project\x1a\xeb\x01\n\tEntityRow\x12\x38\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12U\n\x06\x66ields\x18\x02 \x03(\x0b\x32=.feast.serving.GetOnlineFeaturesRequest.EntityRow.FieldsEntryR\x06\x66ields\x1aM\n\x0b\x46ieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12(\n\x05value\x18\x02 \x01(\x0b\x32\x12.feast.types.ValueR\x05value:\x02\x38\x01\"\xee\x03\n\x1bGetOnlineFeaturesResponseV2\x12Y\n\x0c\x66ield_values\x18\x01 \x03(\x0b\x32\x36.feast.serving.GetOnlineFeaturesResponseV2.FieldValuesR\x0b\x66ieldValues\x1a\xf3\x02\n\x0b\x46ieldValues\x12Z\n\x06\x66ields\x18\x01 \x03(\x0b\x32\x42.feast.serving.GetOnlineFeaturesResponseV2.FieldValues.FieldsEntryR\x06\x66ields\x12`\n\x08statuses\x18\x02 \x03(\x0b\x32\x44.feast.serving.GetOnlineFeaturesResponseV2.FieldValues.StatusesEntryR\x08statuses\x1aM\n\x0b\x46ieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12(\n\x05value\x18\x02 \x01(\x0b\x32\x12.feast.types.ValueR\x05value:\x02\x38\x01\x1aW\n\rStatusesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0e\x32\x1a.feast.serving.FieldStatusR\x05value:\x02\x38\x01\"\xac\x02\n\x19GetOnlineFeaturesResponse\x12L\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.feast.serving.GetOnlineFeaturesResponseMetadataR\x08metadata\x12N\n\x07results\x18\x02 \x03(\x0b\x32\x34.feast.serving.GetOnlineFeaturesResponse.FieldVectorR\x07results\x1aq\n\x0b\x46ieldVector\x12*\n\x06values\x18\x01 \x03(\x0b\x32\x12.feast.types.ValueR\x06values\x12\x36\n\x08statuses\x18\x02 \x03(\x0e\x32\x1a.feast.serving.FieldStatusR\x08statuses\"^\n!GetOnlineFeaturesResponseMetadata\x12\x39\n\x0b\x66ield_names\x18\x01 \x01(\x0b\x32\x18.feast.serving.FieldListR\nfieldNames\"\x1d\n\tFieldList\x12\x10\n\x03val\x18\x01 \x03(\tR\x03val*r\n\x0b\x46ieldStatus\x12\x0b\n\x07INVALID\x10\x00\x12\x0b\n\x07PRESENT\x10\x01\x12\x0e\n\nNULL_VALUE\x10\x02\x12\r\n\tNOT_FOUND\x10\x03\x12\x13\n\x0fOUTSIDE_MAX_AGE\x10\x04\x12\x15\n\x11INGESTION_FAILURE\x10\x05\x32\xd2\x02\n\x0eServingService\x12l\n\x13GetFeastServingInfo\x12).feast.serving.GetFeastServingInfoRequest\x1a*.feast.serving.GetFeastServingInfoResponse\x12j\n\x13GetOnlineFeaturesV2\x12\'.feast.serving.GetOnlineFeaturesRequest\x1a*.feast.serving.GetOnlineFeaturesResponseV2\x12\x66\n\x11GetOnlineFeatures\x12\'.feast.serving.GetOnlineFeaturesRequest\x1a(.feast.serving.GetOnlineFeaturesResponseB\x85\x01\n!dev.caraml.store.protobuf.servingB\x13ServingServiceProtoZKgithub.com/caraml-dev/caraml-store/caraml-store-sdk/go/protos/feast/servingb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'feast.serving.ServingService_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!dev.caraml.store.protobuf.servingB\023ServingServiceProtoZKgithub.com/caraml-dev/caraml-store/caraml-store-sdk/go/protos/feast/serving'
  _GETONLINEFEATURESREQUEST_ENTITYROW_FIELDSENTRY._options = None
  _GETONLINEFEATURESREQUEST_ENTITYROW_FIELDSENTRY._serialized_options = b'8\001'
  _GETONLINEFEATURESRESPONSEV2_FIELDVALUES_FIELDSENTRY._options = None
  _GETONLINEFEATURESRESPONSEV2_FIELDVALUES_FIELDSENTRY._serialized_options = b'8\001'
  _GETONLINEFEATURESRESPONSEV2_FIELDVALUES_STATUSESENTRY._options = None
  _GETONLINEFEATURESRESPONSEV2_FIELDVALUES_STATUSESENTRY._serialized_options = b'8\001'
  _FIELDSTATUS._serialized_start=1640
  _FIELDSTATUS._serialized_end=1754
  _GETFEASTSERVINGINFOREQUEST._serialized_start=111
  _GETFEASTSERVINGINFOREQUEST._serialized_end=139
  _GETFEASTSERVINGINFORESPONSE._serialized_start=141
  _GETFEASTSERVINGINFORESPONSE._serialized_end=196
  _FEATUREREFERENCE._serialized_start=198
  _FEATUREREFERENCE._serialized_end=273
  _GETONLINEFEATURESREQUEST._serialized_start=276
  _GETONLINEFEATURESREQUEST._serialized_end=711
  _GETONLINEFEATURESREQUEST_ENTITYROW._serialized_start=476
  _GETONLINEFEATURESREQUEST_ENTITYROW._serialized_end=711
  _GETONLINEFEATURESREQUEST_ENTITYROW_FIELDSENTRY._serialized_start=634
  _GETONLINEFEATURESREQUEST_ENTITYROW_FIELDSENTRY._serialized_end=711
  _GETONLINEFEATURESRESPONSEV2._serialized_start=714
  _GETONLINEFEATURESRESPONSEV2._serialized_end=1208
  _GETONLINEFEATURESRESPONSEV2_FIELDVALUES._serialized_start=837
  _GETONLINEFEATURESRESPONSEV2_FIELDVALUES._serialized_end=1208
  _GETONLINEFEATURESRESPONSEV2_FIELDVALUES_FIELDSENTRY._serialized_start=634
  _GETONLINEFEATURESRESPONSEV2_FIELDVALUES_FIELDSENTRY._serialized_end=711
  _GETONLINEFEATURESRESPONSEV2_FIELDVALUES_STATUSESENTRY._serialized_start=1121
  _GETONLINEFEATURESRESPONSEV2_FIELDVALUES_STATUSESENTRY._serialized_end=1208
  _GETONLINEFEATURESRESPONSE._serialized_start=1211
  _GETONLINEFEATURESRESPONSE._serialized_end=1511
  _GETONLINEFEATURESRESPONSE_FIELDVECTOR._serialized_start=1398
  _GETONLINEFEATURESRESPONSE_FIELDVECTOR._serialized_end=1511
  _GETONLINEFEATURESRESPONSEMETADATA._serialized_start=1513
  _GETONLINEFEATURESRESPONSEMETADATA._serialized_end=1607
  _FIELDLIST._serialized_start=1609
  _FIELDLIST._serialized_end=1638
  _SERVINGSERVICE._serialized_start=1757
  _SERVINGSERVICE._serialized_end=2095
# @@protoc_insertion_point(module_scope)



from feast.core import DataFormat_pb2 as _DataFormat_pb2
from feast.core import SparkOverride_pb2 as _SparkOverride_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DataSource(_message.Message):
    __slots__ = ["bigquery_options", "created_timestamp_column", "date_partition_column", "event_timestamp_column", "field_mapping", "file_options", "kafka_options", "type"]
    class SourceType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class BigQueryOptions(_message.Message):
        __slots__ = ["spark_override", "table_ref"]
        SPARK_OVERRIDE_FIELD_NUMBER: _ClassVar[int]
        TABLE_REF_FIELD_NUMBER: _ClassVar[int]
        spark_override: _SparkOverride_pb2.SparkOverride
        table_ref: str
        def __init__(self, table_ref: _Optional[str] = ..., spark_override: _Optional[_Union[_SparkOverride_pb2.SparkOverride, _Mapping]] = ...) -> None: ...
    class FieldMappingEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    class FileOptions(_message.Message):
        __slots__ = ["file_format", "file_url", "spark_override"]
        FILE_FORMAT_FIELD_NUMBER: _ClassVar[int]
        FILE_URL_FIELD_NUMBER: _ClassVar[int]
        SPARK_OVERRIDE_FIELD_NUMBER: _ClassVar[int]
        file_format: _DataFormat_pb2.FileFormat
        file_url: str
        spark_override: _SparkOverride_pb2.SparkOverride
        def __init__(self, file_format: _Optional[_Union[_DataFormat_pb2.FileFormat, _Mapping]] = ..., file_url: _Optional[str] = ..., spark_override: _Optional[_Union[_SparkOverride_pb2.SparkOverride, _Mapping]] = ...) -> None: ...
    class KafkaOptions(_message.Message):
        __slots__ = ["bootstrap_servers", "message_format", "spark_override", "topic"]
        BOOTSTRAP_SERVERS_FIELD_NUMBER: _ClassVar[int]
        MESSAGE_FORMAT_FIELD_NUMBER: _ClassVar[int]
        SPARK_OVERRIDE_FIELD_NUMBER: _ClassVar[int]
        TOPIC_FIELD_NUMBER: _ClassVar[int]
        bootstrap_servers: str
        message_format: _DataFormat_pb2.StreamFormat
        spark_override: _SparkOverride_pb2.SparkOverride
        topic: str
        def __init__(self, bootstrap_servers: _Optional[str] = ..., topic: _Optional[str] = ..., message_format: _Optional[_Union[_DataFormat_pb2.StreamFormat, _Mapping]] = ..., spark_override: _Optional[_Union[_SparkOverride_pb2.SparkOverride, _Mapping]] = ...) -> None: ...
    BATCH_BIGQUERY: DataSource.SourceType
    BATCH_FILE: DataSource.SourceType
    BIGQUERY_OPTIONS_FIELD_NUMBER: _ClassVar[int]
    CREATED_TIMESTAMP_COLUMN_FIELD_NUMBER: _ClassVar[int]
    DATE_PARTITION_COLUMN_FIELD_NUMBER: _ClassVar[int]
    EVENT_TIMESTAMP_COLUMN_FIELD_NUMBER: _ClassVar[int]
    FIELD_MAPPING_FIELD_NUMBER: _ClassVar[int]
    FILE_OPTIONS_FIELD_NUMBER: _ClassVar[int]
    INVALID: DataSource.SourceType
    KAFKA_OPTIONS_FIELD_NUMBER: _ClassVar[int]
    STREAM_KAFKA: DataSource.SourceType
    TYPE_FIELD_NUMBER: _ClassVar[int]
    bigquery_options: DataSource.BigQueryOptions
    created_timestamp_column: str
    date_partition_column: str
    event_timestamp_column: str
    field_mapping: _containers.ScalarMap[str, str]
    file_options: DataSource.FileOptions
    kafka_options: DataSource.KafkaOptions
    type: DataSource.SourceType
    def __init__(self, type: _Optional[_Union[DataSource.SourceType, str]] = ..., field_mapping: _Optional[_Mapping[str, str]] = ..., event_timestamp_column: _Optional[str] = ..., date_partition_column: _Optional[str] = ..., created_timestamp_column: _Optional[str] = ..., file_options: _Optional[_Union[DataSource.FileOptions, _Mapping]] = ..., bigquery_options: _Optional[_Union[DataSource.BigQueryOptions, _Mapping]] = ..., kafka_options: _Optional[_Union[DataSource.KafkaOptions, _Mapping]] = ...) -> None: ...



from feast.types import Value_pb2 as _Value_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Entity(_message.Message):
    __slots__ = ["meta", "spec"]
    META_FIELD_NUMBER: _ClassVar[int]
    SPEC_FIELD_NUMBER: _ClassVar[int]
    meta: EntityMeta
    spec: EntitySpec
    def __init__(self, spec: _Optional[_Union[EntitySpec, _Mapping]] = ..., meta: _Optional[_Union[EntityMeta, _Mapping]] = ...) -> None: ...

class EntityMeta(_message.Message):
    __slots__ = ["created_timestamp", "last_updated_timestamp"]
    CREATED_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    LAST_UPDATED_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    created_timestamp: _timestamp_pb2.Timestamp
    last_updated_timestamp: _timestamp_pb2.Timestamp
    def __init__(self, created_timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., last_updated_timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class EntitySpec(_message.Message):
    __slots__ = ["description", "labels", "name", "value_type"]
    class LabelsEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    VALUE_TYPE_FIELD_NUMBER: _ClassVar[int]
    description: str
    labels: _containers.ScalarMap[str, str]
    name: str
    value_type: _Value_pb2.ValueType.Enum
    def __init__(self, name: _Optional[str] = ..., value_type: _Optional[_Union[_Value_pb2.ValueType.Enum, str]] = ..., description: _Optional[str] = ..., labels: _Optional[_Mapping[str, str]] = ...) -> None: ...



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

BIGTABLE: StoreType
DESCRIPTOR: _descriptor.FileDescriptor
REDIS: StoreType
UNSET: StoreType

class OnlineStore(_message.Message):
    __slots__ = ["description", "name", "type"]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    description: str
    name: str
    type: StoreType
    def __init__(self, name: _Optional[str] = ..., type: _Optional[_Union[StoreType, str]] = ..., description: _Optional[str] = ...) -> None: ...

class StoreType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class BoolList(_message.Message):
    __slots__ = ["val"]
    VAL_FIELD_NUMBER: _ClassVar[int]
    val: _containers.RepeatedScalarFieldContainer[bool]
    def __init__(self, val: _Optional[_Iterable[bool]] = ...) -> None: ...

class BytesList(_message.Message):
    __slots__ = ["val"]
    VAL_FIELD_NUMBER: _ClassVar[int]
    val: _containers.RepeatedScalarFieldContainer[bytes]
    def __init__(self, val: _Optional[_Iterable[bytes]] = ...) -> None: ...

class DoubleList(_message.Message):
    __slots__ = ["val"]
    VAL_FIELD_NUMBER: _ClassVar[int]
    val: _containers.RepeatedScalarFieldContainer[float]
    def __init__(self, val: _Optional[_Iterable[float]] = ...) -> None: ...

class FloatList(_message.Message):
    __slots__ = ["val"]
    VAL_FIELD_NUMBER: _ClassVar[int]
    val: _containers.RepeatedScalarFieldContainer[float]
    def __init__(self, val: _Optional[_Iterable[float]] = ...) -> None: ...

class Int32List(_message.Message):
    __slots__ = ["val"]
    VAL_FIELD_NUMBER: _ClassVar[int]
    val: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, val: _Optional[_Iterable[int]] = ...) -> None: ...

class Int64List(_message.Message):
    __slots__ = ["val"]
    VAL_FIELD_NUMBER: _ClassVar[int]
    val: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, val: _Optional[_Iterable[int]] = ...) -> None: ...

class StringList(_message.Message):
    __slots__ = ["val"]
    VAL_FIELD_NUMBER: _ClassVar[int]
    val: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, val: _Optional[_Iterable[str]] = ...) -> None: ...

class Value(_message.Message):
    __slots__ = ["bool_list_val", "bool_val", "bytes_list_val", "bytes_val", "double_list_val", "double_val", "float_list_val", "float_val", "int32_list_val", "int32_val", "int64_list_val", "int64_val", "string_list_val", "string_val"]
    BOOL_LIST_VAL_FIELD_NUMBER: _ClassVar[int]
    BOOL_VAL_FIELD_NUMBER: _ClassVar[int]
    BYTES_LIST_VAL_FIELD_NUMBER: _ClassVar[int]
    BYTES_VAL_FIELD_NUMBER: _ClassVar[int]
    DOUBLE_LIST_VAL_FIELD_NUMBER: _ClassVar[int]
    DOUBLE_VAL_FIELD_NUMBER: _ClassVar[int]
    FLOAT_LIST_VAL_FIELD_NUMBER: _ClassVar[int]
    FLOAT_VAL_FIELD_NUMBER: _ClassVar[int]
    INT32_LIST_VAL_FIELD_NUMBER: _ClassVar[int]
    INT32_VAL_FIELD_NUMBER: _ClassVar[int]
    INT64_LIST_VAL_FIELD_NUMBER: _ClassVar[int]
    INT64_VAL_FIELD_NUMBER: _ClassVar[int]
    STRING_LIST_VAL_FIELD_NUMBER: _ClassVar[int]
    STRING_VAL_FIELD_NUMBER: _ClassVar[int]
    bool_list_val: BoolList
    bool_val: bool
    bytes_list_val: BytesList
    bytes_val: bytes
    double_list_val: DoubleList
    double_val: float
    float_list_val: FloatList
    float_val: float
    int32_list_val: Int32List
    int32_val: int
    int64_list_val: Int64List
    int64_val: int
    string_list_val: StringList
    string_val: str
    def __init__(self, bytes_val: _Optional[bytes] = ..., string_val: _Optional[str] = ..., int32_val: _Optional[int] = ..., int64_val: _Optional[int] = ..., double_val: _Optional[float] = ..., float_val: _Optional[float] = ..., bool_val: bool = ..., bytes_list_val: _Optional[_Union[BytesList, _Mapping]] = ..., string_list_val: _Optional[_Union[StringList, _Mapping]] = ..., int32_list_val: _Optional[_Union[Int32List, _Mapping]] = ..., int64_list_val: _Optional[_Union[Int64List, _Mapping]] = ..., double_list_val: _Optional[_Union[DoubleList, _Mapping]] = ..., float_list_val: _Optional[_Union[FloatList, _Mapping]] = ..., bool_list_val: _Optional[_Union[BoolList, _Mapping]] = ...) -> None: ...

class ValueType(_message.Message):
    __slots__ = []
    class Enum(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    BOOL: ValueType.Enum
    BOOL_LIST: ValueType.Enum
    BYTES: ValueType.Enum
    BYTES_LIST: ValueType.Enum
    DOUBLE: ValueType.Enum
    DOUBLE_LIST: ValueType.Enum
    FLOAT: ValueType.Enum
    FLOAT_LIST: ValueType.Enum
    INT32: ValueType.Enum
    INT32_LIST: ValueType.Enum
    INT64: ValueType.Enum
    INT64_LIST: ValueType.Enum
    INVALID: ValueType.Enum
    STRING: ValueType.Enum
    STRING_LIST: ValueType.Enum
    def __init__(self) -> None: ...



from feast.types import Value_pb2 as _Value_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class FeatureSpec(_message.Message):
    __slots__ = ["labels", "name", "value_type"]
    class LabelsEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    LABELS_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    VALUE_TYPE_FIELD_NUMBER: _ClassVar[int]
    labels: _containers.ScalarMap[str, str]
    name: str
    value_type: _Value_pb2.ValueType.Enum
    def __init__(self, name: _Optional[str] = ..., value_type: _Optional[_Union[_Value_pb2.ValueType.Enum, str]] = ..., labels: _Optional[_Mapping[str, str]] = ...) -> None: ...
